###############################################################################
#
# ChemSymbols - a function containing the unicode strings for special characters
# that are common in chemistry
#
###############################################################################


def _enclose(text, html_center):
    if type(text) == str and type(html_center) == str:
        return '<' + html_center + '>' + text + '</' + html_center + '>'
    else:
        raise NameError('Please provide a string argument')

def textsub(text):
    """
    Return a piece of text that has added HTML subscript tags.
    
    Required Args:
        text (string): text that should be subscripted
        
    Returns:
        (string): subscripted text with HTML tags
    """
    return _enclose(text, 'sub')

def textsup(text):
    """
    Return a piece of text that has added HTML superscript tags.
    
    Required Args:
        text (string): text that should be superscripted
        
    Returns:
        (string): superscripted text with HTML tags
    """
    return _enclose(text, 'sup')

def textit(text):
    """
    Return a piece of text that has added HTML italics tags.
    
    Required Args:
        text (string): text that should be italicized
        
    Returns:
        (string): italicized text with HTML tags
    """
    return _enclose(text, 'i')

def textbf(text):
    """
    Return a piece of text that has added HTML bold face tags.
    
    Required Args:
        text (string): text that should be bold faced
        
    Returns:
        (string): bold face text with HTML tags
    """
    return _enclose(text, 'b')





